@@ -6,7 +6,7 @@ use strictures 1;
 use Padre::Unload                            ();
 use Padre::Plugin::Git::FBP::Output ();
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use parent qw(
 	Padre::Plugin::Git::FBP::Output
 	Padre::Plugin
@@ -37,6 +37,9 @@ sub new {
 
 __END__
 
+# Spider bait
+Perl programming -> TIOBE
+
 =pod
 
 =head1 NAME
@@ -45,7 +48,7 @@ Padre::Plugin::Git::Output - Git plugin for Padre, The Perl IDE.
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
